@@ -1,5 +1,7 @@
 # system configuration generated and used by the sysconfig module
-build_time_vars = {'ABIFLAGS': '',
+build_time_vars = {'ABI3DLLLIBRARY': 'msys-python3.dll',
+ 'ABI3LDLIBRARY': 'libpython3.dll.a',
+ 'ABIFLAGS': '',
  'AC_APPLE_UNIVERSAL_BUILD': 0,
  'AIX_BUILDDATE': 0,
  'AIX_GENUINE_CPLUSPLUS': 0,
@@ -59,9 +61,9 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.12',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/t/python/src/Python-3.12.8/coverage.info',
+ 'COVERAGE_INFO': '/t/python/src/Python-3.12.12/coverage.info',
  'COVERAGE_LCOV_OPTIONS': '--rc lcov_branch_coverage=1',
- 'COVERAGE_REPORT': '/t/python/src/Python-3.12.8/lcov-report',
+ 'COVERAGE_REPORT': '/t/python/src/Python-3.12.12/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--rc lcov_branch_coverage=1 --branch-coverage '
                             '--title "CPython 3.12 LCOV report [commit $(shell '
                             ')]"',
@@ -538,6 +540,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_SYS_MODEM_H': 0,
  'HAVE_SYS_NDIR_H': 0,
  'HAVE_SYS_PARAM_H': 1,
+ 'HAVE_SYS_PIDFD_H': 0,
  'HAVE_SYS_POLL_H': 1,
  'HAVE_SYS_RANDOM_H': 1,
  'HAVE_SYS_RESOURCE_H': 1,
@@ -571,7 +574,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_TMPNAM_R': 0,
  'HAVE_TM_ZONE': 1,
  'HAVE_TRUNCATE': 1,
- 'HAVE_TTYNAME': 1,
+ 'HAVE_TTYNAME_R': 1,
  'HAVE_TZNAME': 0,
  'HAVE_UMASK': 1,
  'HAVE_UNAME': 1,
@@ -1219,8 +1222,8 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 1,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/t/python/src/Python-3.12.8',
- 'abs_srcdir': '/t/python/src/Python-3.12.8',
+ 'abs_builddir': '/t/python/src/Python-3.12.12',
+ 'abs_srcdir': '/t/python/src/Python-3.12.12',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
